@@ -6,6 +6,18 @@ A module implementing a floating-point primitive interface.
 from runtimepy.primitives.base import Primitive as _Primitive
 from runtimepy.primitives.type.float import Double as _Double
 from runtimepy.primitives.type.float import Float as _Float
+from runtimepy.primitives.type.float import Half as _Half
+
+
+class HalfPrimitive(_Primitive[float]):
+    """A simple primitive class for single-precision floating-point."""
+
+    def __init__(self, *_, value: float = 0.0) -> None:
+        """Initialize this floating-point primitive."""
+        super().__init__(_Half, value=value)
+
+
+Half = HalfPrimitive
 
 
 class FloatPrimitive(_Primitive[float]):
